function r = MRLPF(mpc)
% This function calls the LPF assuming all the voltage are in D1.
% The load parameters are updated using the first LPF solution.
% Final solution is given by calling the LPF for the second time using
% the updated load parameters. All loads are modeled as constant-power.
% Further details about the MR-LPF algorithm can be found in the following
% paper:
% H. Ahmadi, J. R. Marti, and E. Vaahedi, The multi-region linear power 
% flow formulation, submitted to the IEEE Power Engineering Letters, 2015.
% -------------------------------------------------------------------------
% 
%                  Copyright (C) 2015  Hamed Ahmadi
% 
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% -------------------------------------------------------------------------
CZ = -1*ones(size(mpc.bus(:,1)));CI = 2*ones(size(mpc.bus(:,1)));
r = LPF_modified(mpc,CZ,CI);
% Check for voltages in D0
V_index = and(r(:,2)<1.15,r(:,2)>=1.05);
CZ(V_index) = -0.825;CI(V_index) = 1.817;
% Check for voltages in D1
V_index = and(r(:,2)<1.05,r(:,2)>=0.95);
CZ(V_index) = -1;CI(V_index) = 2;
% Check for voltages in D2
V_index = and(r(:,2)<0.95,r(:,2)>=0.85);
CZ(V_index) = -1.232;CI(V_index) = 2.221;
% Check for voltages in D3
V_index = and(r(:,2)<0.85,r(:,2)>=0.75);
CZ(V_index) = -1.559;CI(V_index) = 2.499;
% Check for voltages in D4
V_index = and(r(:,2)<0.75,r(:,2)>=0.65);
CZ(V_index) = -2.036;CI(V_index) = 2.856;
% Run the LPF using the corrected parameters
r = LPF_modified(mpc,CZ,CI);
end